@@ -1,5 +1,5 @@
 /* This file is part of GNU Rush.                  
-   Copyright (C) 2008, 2009, 2010 Sergey Poznyakoff
+   Copyright (C) 2008, 2009 Sergey Poznyakoff
 
    GNU Rush is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -296,7 +296,7 @@ void parse_config(void);
 void set_error_msg(enum error_type type, char *text);
 int string_to_error_index(const char *name);
 
-transform_t compile_transform_expr (const char *expr, int cflags);
+transform_t compile_transform_expr (const char *expr);
 char *transform_string (struct transform *tf, const char *input);
 
 int post_socket_send(const struct rush_sockaddr *sockaddr,
